@@ -1,16 +1,41 @@
 /* ks.c
-   this file is copy from R-2.15.0.
+   this file is copied from R-4.2.0.
 */
 
 #include "QTLRelR.h"
 
+/*
+ *  R : A Computer Language for Statistical Data Analysis
+ *  Copyright (C) 1999-2022   The R Core Team.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, a copy is available at
+ *  https://www.R-project.org/Licenses/
+ */
+
+/* ks.c
+   Compute the asymptotic distribution of the one- and two-sample
+   two-sided Kolmogorov-Smirnov statistics, and the exact distributions
+   in the two-sided one-sample and two-sample cases.
+*/
+
 static double K(int n, double d);
 static void m_multiply(double *A, double *B, double *C, int m);
 static void m_power(double *A, int eA, double *V, int *eV, int m, int n);
 
 /* Two-sample two-sided asymptotic distribution */
-void
-pkstwo(Sint *n, double *x, double *tol)
+static void
+pkstwo(int n, double *x, double tol)
 {
 /* x[1:n] is input and output
  *
@@ -33,11 +58,11 @@ pkstwo(Sint *n, double *x, double *tol)
  *
  */
     double new, old, s, w, z;
-    Sint i, k, k_max;
+    int i, k, k_max;
 
-    k_max = (Sint) sqrt(2 - log(*tol));
+    k_max = (int) sqrt(2 - log(tol));
 
-    for(i = 0; i < *n; i++) {
+    for(i = 0; i < n; i++) {
 	if(x[i] < 1) {
 	    z = - (M_PI_2 * M_PI_4) / (x[i] * x[i]);
 	    w = log(x[i]);
@@ -53,7 +78,7 @@ pkstwo(Sint *n, double *x, double *tol)
 	    k = 1;
 	    old = 0;
 	    new = 1;
-	    while(fabs(old - new) > *tol) {
+	    while(fabs(old - new) > tol) {
 		old = new;
 		new += 2 * s * exp(z * k * k);
 		s *= -1;
@@ -65,51 +90,41 @@ pkstwo(Sint *n, double *x, double *tol)
 }
 
 /* Two-sided two-sample */
-void
-psmirnov2x(double *x, Sint *m, Sint *n)
+static double psmirnov2x(double *x, int m, int n)
 {
     double md, nd, q, *u, w;
-    Sint i, j;
+    int i, j;
 
-    if(*m > *n) {
-	i = *n; *n = *m; *m = i;
+    if(m > n) {
+	i = n; n = m; m = i;
     }
-    md = (double) (*m);
-    nd = (double) (*n);
+    md = (double) m;
+    nd = (double) n;
     /*
        q has 0.5/mn added to ensure that rounding error doesn't
        turn an equality into an inequality, eg abs(1/2-4/5)>3/10 
 
     */
     q = (0.5 + floor(*x * md * nd - 1e-7)) / (md * nd);
-    u = (double *) R_alloc(*n + 1, sizeof(double));
+    u = (double *) R_alloc(n + 1, sizeof(double));
 
-    for(j = 0; j <= *n; j++) {
+    for(j = 0; j <= n; j++) {
 	u[j] = ((j / nd) > q) ? 0 : 1;
     }
-    for(i = 1; i <= *m; i++) {
-	w = (double)(i) / ((double)(i + *n));
+    for(i = 1; i <= m; i++) {
+	w = (double)(i) / ((double)(i + n));
 	if((i / md) > q)
 	    u[0] = 0;
 	else
 	    u[0] = w * u[0];
-	for(j = 1; j <= *n; j++) {
+	for(j = 1; j <= n; j++) {
 	    if(fabs(i / md - j / nd) > q) 
 		u[j] = 0;
 	    else
 		u[j] = w * u[j] + u[j - 1];
 	}
     }
-    *x = u[*n];
-}
-
-/* The two-sided one-sample 'exact' distribution */
-void
-pkolmogorov2x(double *x, Sint *n)
-{
-    /* x is input and output. */
-
-    *x = K(*n, *x);
+    return u[n];
 }
 
 static double
@@ -135,8 +150,8 @@ K(int n, double d)
    k = (int) (n * d) + 1;
    m = 2 * k - 1;
    h = k - n * d;
-   H = (double*) Calloc(m * m, double);
-   Q = (double*) Calloc(m * m, double);
+   H = (double*) R_Calloc(m * m, double);
+   Q = (double*) R_Calloc(m * m, double);
    for(i = 0; i < m; i++)
        for(j = 0; j < m; j++)
 	   if(i - j + 1 < 0)
@@ -144,12 +159,12 @@ K(int n, double d)
 	   else
 	       H[i * m + j] = 1;
    for(i = 0; i < m; i++) {
-       H[i * m] -= pow(h, i + 1);
-       H[(m - 1) * m + i] -= pow(h, (m - i));
+       H[i * m] -= R_pow_di(h, i + 1);
+       H[(m - 1) * m + i] -= R_pow_di(h, (m - i));
    }
-   H[(m - 1) * m] += ((2 * h - 1 > 0) ? pow(2 * h - 1, m) : 0);
+   H[(m - 1) * m] += ((2 * h - 1 > 0) ? R_pow_di(2 * h - 1, m) : 0);
    for(i = 0; i < m; i++)
-       for(j=0; j < m; j++)
+       for(j = 0; j < m; j++)
 	   if(i - j + 1 > 0)
 	       for(g = 1; g <= i - j + 1; g++)
 		   H[i * m + j] /= g;
@@ -163,9 +178,9 @@ K(int n, double d)
 	   eQ -= 140;
        }
    }
-   s *= pow(10., eQ);
-   Free(H);
-   Free(Q);
+   s *= R_pow_di(10.0, eQ);
+   R_Free(H);
+   R_Free(Q);
    return(s);
 }
 
@@ -202,7 +217,7 @@ m_power(double *A, int eA, double *V, int *eV, int m, int n)
 	return;
     }
     m_power(A, eA, V, eV, m, n / 2);
-    B = (double*) Calloc(m * m, double);
+    B = (double*) R_Calloc(m * m, double);
     m_multiply(V, V, B, m);
     eB = 2 * (*eV);
     if((n % 2) == 0) {
@@ -219,5 +234,23 @@ m_power(double *A, int eA, double *V, int *eV, int m, int n)
 	    V[i] = V[i] * 1e-140;
 	*eV += 140;
     }
-    Free(B);
+    R_Free(B);
 }
+
+/* Two-sided two-sample */
+SEXP pSmirnov2x(SEXP statistic, SEXP snx, SEXP sny)
+{
+    int nx = asInteger(snx), ny = asInteger(sny);
+    double st = asReal(statistic);
+    return ScalarReal(psmirnov2x(&st, nx, ny));
+}
+
+/* The two-sided one-sample 'exact' distribution */
+SEXP pKolmogorov2x(SEXP statistic, SEXP sn)
+{
+    int n = asInteger(sn);
+    double st = asReal(statistic), p;
+    p = K(n, st);
+    return ScalarReal(p);
+}
+
